==> tuia-advert-center-api-2.2.22-sources.jar: cn/com/duiba/tuia/core/api/statistics/domain/CenterEndPointDataRsp.java <==
package cn.com.duiba.tuia.core.api.statistics.domain;

public class CenterEndPointDataRsp {

    //基础数据
    private Long advertId;

    private Long appId;

    private Long slotId;

    //后端转化pv
    private Long installPv;

    private Long startPv;

    private Long registePv;

    private Long activatePv;

    private Long loginPv;

    private Long payPv;

    private Long entryPv;

    private Long finishPv;

    //后端转化uv
    private Long installUv;

    private Long startUv;

    private Long registeUv;

    private Long activateUv;

    private Long loginUv;

    private Long payUv;

    private Long entryUv;

    private Long finishUv;


    public Long getAdvertId() {
        return advertId;
    }

    public void setAdvertId(Long advertId) {
        this.advertId = advertId;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Long getSlotId() {
        return slotId;
    }

    public void setSlotId(Long slotId) {
        this.slotId = slotId;
    }

    public Long getInstallPv() {
        return installPv;
    }

    public void setInstallPv(Long installPv) {
        this.installPv = installPv;
    }

    public Long getStartPv() {
        return startPv;
    }

    public void setStartPv(Long startPv) {
        this.startPv = startPv;
    }

    public Long getRegistePv() {
        return registePv;
    }

    public void setRegistePv(Long registePv) {
        this.registePv = registePv;
    }

    public Long getActivatePv() {
        return activatePv;
    }

    public void setActivatePv(Long activatePv) {
        this.activatePv = activatePv;
    }

    public Long getLoginPv() {
        return loginPv;
    }

    public void setLoginPv(Long loginPv) {
        this.loginPv = loginPv;
    }

    public Long getPayPv() {
        return payPv;
    }

    public void setPayPv(Long payPv) {
        this.payPv = payPv;
    }

    public Long getEntryPv() {
        return entryPv;
    }

    public void setEntryPv(Long entryPv) {
        this.entryPv = entryPv;
    }

    public Long getFinishPv() {
        return finishPv;
    }

    public void setFinishPv(Long finishPv) {
        this.finishPv = finishPv;
    }

    public Long getInstallUv() {
        return installUv;
    }

    public void setInstallUv(Long installUv) {
        this.installUv = installUv;
    }

    public Long getStartUv() {
        return startUv;
    }

    public void setStartUv(Long startUv) {
        this.startUv = startUv;
    }

    public Long getRegisteUv() {
        return registeUv;
    }

    public void setRegisteUv(Long registeUv) {
        this.registeUv = registeUv;
    }

    public Long getActivateUv() {
        return activateUv;
    }

    public void setActivateUv(Long activateUv) {
        this.activateUv = activateUv;
    }

    public Long getLoginUv() {
        return loginUv;
    }

    public void setLoginUv(Long loginUv) {
        this.loginUv = loginUv;
    }

    public Long getPayUv() {
        return payUv;
    }

    public void setPayUv(Long payUv) {
        this.payUv = payUv;
    }

    public Long getEntryUv() {
        return entryUv;
    }

    public void setEntryUv(Long entryUv) {
        this.entryUv = entryUv;
    }

    public Long getFinishUv() {
        return finishUv;
    }

    public void setFinishUv(Long finishUv) {
        this.finishUv = finishUv;
    }
}

==> tuia-advert-center-api-2.3.47-sources.jar: cn/com/duiba/tuia/core/api/statistics/domain/CenterEndPointDataRsp.java <==
package cn.com.duiba.tuia.core.api.statistics.domain;

import java.util.Date;

public class CenterEndPointDataRsp {

    //基础数据
    private Long advertId;

    private Long appId;

    private Long slotId;

    //后端转化pv
    private Long installPv;

    private Long startPv;

    private Long registePv;

    private Long activatePv;

    private Long loginPv;

    private Long payPv;

    private Long entryPv;

    private Long finishPv;

    //后端转化uv
    private Long installUv;

    private Long startUv;

    private Long registeUv;

    private Long activateUv;

    private Long loginUv;

    private Long payUv;

    private Long entryUv;

    private Long finishUv;

    private Date curDate;


    public Long getAdvertId() {
        return advertId;
    }

    public void setAdvertId(Long advertId) {
        this.advertId = advertId;
    }

    public Long getAppId() {
        return appId;
    }

    public void setAppId(Long appId) {
        this.appId = appId;
    }

    public Long getSlotId() {
        return slotId;
    }

    public void setSlotId(Long slotId) {
        this.slotId = slotId;
    }

    public Long getInstallPv() {
        return installPv;
    }

    public void setInstallPv(Long installPv) {
        this.installPv = installPv;
    }

    public Long getStartPv() {
        return startPv;
    }

    public void setStartPv(Long startPv) {
        this.startPv = startPv;
    }

    public Long getRegistePv() {
        return registePv;
    }

    public void setRegistePv(Long registePv) {
        this.registePv = registePv;
    }

    public Long getActivatePv() {
        return activatePv;
    }

    public void setActivatePv(Long activatePv) {
        this.activatePv = activatePv;
    }

    public Long getLoginPv() {
        return loginPv;
    }

    public void setLoginPv(Long loginPv) {
        this.loginPv = loginPv;
    }

    public Long getPayPv() {
        return payPv;
    }

    public void setPayPv(Long payPv) {
        this.payPv = payPv;
    }

    public Long getEntryPv() {
        return entryPv;
    }

    public void setEntryPv(Long entryPv) {
        this.entryPv = entryPv;
    }

    public Long getFinishPv() {
        return finishPv;
    }

    public void setFinishPv(Long finishPv) {
        this.finishPv = finishPv;
    }

    public Long getInstallUv() {
        return installUv;
    }

    public void setInstallUv(Long installUv) {
        this.installUv = installUv;
    }

    public Long getStartUv() {
        return startUv;
    }

    public void setStartUv(Long startUv) {
        this.startUv = startUv;
    }

    public Long getRegisteUv() {
        return registeUv;
    }

    public void setRegisteUv(Long registeUv) {
        this.registeUv = registeUv;
    }

    public Long getActivateUv() {
        return activateUv;
    }

    public void setActivateUv(Long activateUv) {
        this.activateUv = activateUv;
    }

    public Long getLoginUv() {
        return loginUv;
    }

    public void setLoginUv(Long loginUv) {
        this.loginUv = loginUv;
    }

    public Long getPayUv() {
        return payUv;
    }

    public void setPayUv(Long payUv) {
        this.payUv = payUv;
    }

    public Long getEntryUv() {
        return entryUv;
    }

    public void setEntryUv(Long entryUv) {
        this.entryUv = entryUv;
    }

    public Long getFinishUv() {
        return finishUv;
    }

    public void setFinishUv(Long finishUv) {
        this.finishUv = finishUv;
    }

    public Date getCurDate() {
        return curDate;
    }

    public void setCurDate(Date curDate) {
        this.curDate = curDate;
    }
}
